@@ -54,6 +54,7 @@ static gchar    *set_initial_eps_bearer_settings_str;
 static gchar    *disable_facility_lock_str;
 static gchar    *set_packet_service_state_str;
 static gchar    *set_nr5g_registration_settings_str;
+static gchar    *set_carrier_lock_str;
 
 static GOptionEntry entries[] = {
     { "3gpp-scan", 0, 0, G_OPTION_ARG_NONE, &scan_flag,
@@ -88,6 +89,10 @@ static GOptionEntry entries[] = {
       "Set 5GNR registration settings",
       "[\"key=value,...\"]"
     },
+    { "3gpp-set-carrier-lock", 0, 0, G_OPTION_ARG_STRING, &set_carrier_lock_str,
+      "Carrier Lock",
+      "[(Data)]"
+    },
     { NULL }
 };
 
@@ -122,7 +127,8 @@ mmcli_modem_3gpp_options_enabled (void)
                  !!set_initial_eps_bearer_settings_str +
                  !!disable_facility_lock_str +
                  !!set_packet_service_state_str +
-                 !!set_nr5g_registration_settings_str);
+                 !!set_nr5g_registration_settings_str +
+                 !!set_carrier_lock_str);
 
     if (n_actions > 1) {
         g_printerr ("error: too many 3GPP actions requested\n");
@@ -420,6 +426,32 @@ set_nr5g_registration_settings_ready (MMModem3gpp  *modem_3gpp,
     mmcli_async_operation_done ();
 }
 
+static void
+set_carrier_lock_process_reply (gboolean     result,
+                                const GError *error)
+{
+    if (!result) {
+        g_printerr ("error: couldn't send carrier lock information: '%s'\n",
+                    error ? error->message : "unknown error");
+        exit (EXIT_FAILURE);
+    }
+
+    g_print ("successfully sent carrier lock information to modem\n");
+}
+
+static void
+set_carrier_lock_ready (MMModem3gpp  *modem_3gpp,
+                        GAsyncResult *result)
+{
+    gboolean          operation_result;
+    g_autoptr(GError) error = NULL;
+
+    operation_result = mm_modem_3gpp_set_carrier_lock_finish (modem_3gpp, result, &error);
+    set_carrier_lock_process_reply (operation_result, error);
+
+    mmcli_async_operation_done ();
+}
+
 static void
 get_modem_ready (GObject      *source,
                  GAsyncResult *result)
@@ -455,26 +487,25 @@ get_modem_ready (GObject      *source,
         return;
     }
 
-    ensure_modem_enabled ();
+    /* Request to set carrier Lock */
+    if (set_carrier_lock_str) {
+        gsize              data_size  = 0;
+        g_autofree guint8 *data = NULL;
+        GError            *error = NULL;
 
-    /* Request to scan networks? */
-    if (scan_flag) {
-        g_debug ("Asynchronously scanning for networks...");
-        mm_modem_3gpp_scan (ctx->modem_3gpp,
-                            ctx->cancellable,
-                            (GAsyncReadyCallback)scan_ready,
-                            NULL);
-        return;
-    }
+        data = mm_utils_hexstr2bin (set_carrier_lock_str, -1, &data_size, &error);
+        if (!data) {
+            g_printerr ("Failed to read data from the input: %s\n", error->message);
+            exit (EXIT_FAILURE);
+            return;
+        }
 
-    /* Request to register the modem? */
-    if (register_in_operator_str || register_home_flag) {
-        g_debug ("Asynchronously registering the modem...");
-        mm_modem_3gpp_register (ctx->modem_3gpp,
-                                (register_in_operator_str ? register_in_operator_str : ""),
-                                ctx->cancellable,
-                                (GAsyncReadyCallback)register_ready,
-                                NULL);
+        mm_modem_3gpp_set_carrier_lock (ctx->modem_3gpp,
+                                        data,
+                                        (guint32)data_size,
+                                        ctx->cancellable,
+                                        (GAsyncReadyCallback)set_carrier_lock_ready,
+                                        NULL);
         return;
     }
 
@@ -512,7 +543,37 @@ get_modem_ready (GObject      *source,
                                                        NULL);
         g_object_unref (config);
         return;
+    }
 
+    ensure_modem_enabled ();
+
+    /* Request to scan networks? */
+    if (scan_flag) {
+        g_debug ("Asynchronously scanning for networks...");
+
+        /* Setup operation timeout: 5 minutes 17 seconds (to match MM internal
+         * timeout with a bit of slack) */
+        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), ((5 * 60) + 17) * 1000);
+        mm_modem_3gpp_scan (ctx->modem_3gpp,
+                            ctx->cancellable,
+                            (GAsyncReadyCallback)scan_ready,
+                            NULL);
+        return;
+    }
+
+    /* Request to register the modem? */
+    if (register_in_operator_str || register_home_flag) {
+        g_debug ("Asynchronously registering the modem...");
+
+        /* Setup operation timeout: 2 minutes 2 seconds (to match MM internal
+         * timeout with a bit of slack) */
+        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), ((2 * 60) + 2) * 1000);
+        mm_modem_3gpp_register (ctx->modem_3gpp,
+                                (register_in_operator_str ? register_in_operator_str : ""),
+                                ctx->cancellable,
+                                (GAsyncReadyCallback)register_ready,
+                                NULL);
+        return;
     }
 
     /* Request to set packet service state */
@@ -617,19 +678,25 @@ mmcli_modem_3gpp_run_synchronous (GDBusConnection *connection)
         return;
     }
 
-    ensure_modem_enabled ();
+    /* Request to set carrier Lock */
+    if (set_carrier_lock_str) {
+        gsize              data_size  = 0;
+        g_autofree guint8 *data = NULL;
+        gboolean           result;
 
-    /* Request to register the modem? */
-    if (register_in_operator_str || register_home_flag) {
-        gboolean result;
+        data = mm_utils_hexstr2bin (set_carrier_lock_str, -1, &data_size, &error);
+        if (!data) {
+            g_printerr ("Failed to read data from the input: %s\n", error->message);
+            exit (EXIT_FAILURE);
+            return;
+        }
 
-        g_debug ("Synchronously registering the modem...");
-        result = mm_modem_3gpp_register_sync (
-            ctx->modem_3gpp,
-            (register_in_operator_str ? register_in_operator_str : ""),
-            NULL,
-            &error);
-        register_process_reply (result, error);
+        result = mm_modem_3gpp_set_carrier_lock_sync (ctx->modem_3gpp,
+                                                      data,
+                                                      (guint32)data_size,
+                                                      NULL,
+                                                      &error);
+        set_carrier_lock_process_reply (result, error);
         return;
     }
 
@@ -670,6 +737,22 @@ mmcli_modem_3gpp_run_synchronous (GDBusConnection *connection)
         return;
     }
 
+    ensure_modem_enabled ();
+
+    /* Request to register the modem? */
+    if (register_in_operator_str || register_home_flag) {
+        gboolean result;
+
+        g_debug ("Synchronously registering the modem...");
+        result = mm_modem_3gpp_register_sync (
+            ctx->modem_3gpp,
+            (register_in_operator_str ? register_in_operator_str : ""),
+            NULL,
+            &error);
+        register_process_reply (result, error);
+        return;
+    }
+
     /* Request to set packet service state */
     if (set_packet_service_state_str) {
         gboolean                       result;
