@@ -120,6 +120,7 @@ static FieldInfo field_infos[] = {
     [MMC_F_SYSTEM_PLUGIN]                            = { "modem.generic.plugin",                            "plugin",                   MMC_S_MODEM_SYSTEM,               },
     [MMC_F_SYSTEM_PRIMARY_PORT]                      = { "modem.generic.primary-port",                      "primary port",             MMC_S_MODEM_SYSTEM,               },
     [MMC_F_SYSTEM_PORTS]                             = { "modem.generic.ports",                             "ports",                    MMC_S_MODEM_SYSTEM,               },
+    [MMC_F_SYSTEM_IGNORED_PORTS]                     = { "modem.generic.ignored-ports",                     "ignored ports",            MMC_S_MODEM_SYSTEM,               },
     [MMC_F_NUMBERS_OWN]                              = { "modem.generic.own-numbers",                       "own",                      MMC_S_MODEM_NUMBERS,              },
     [MMC_F_STATUS_LOCK]                              = { "modem.generic.unlock-required",                   "lock",                     MMC_S_MODEM_STATUS,               },
     [MMC_F_STATUS_UNLOCK_RETRIES]                    = { "modem.generic.unlock-retries",                    "unlock retries",           MMC_S_MODEM_STATUS,               },
@@ -241,6 +242,7 @@ static FieldInfo field_infos[] = {
     [MMC_F_BEARER_STATUS_CONNECTED]                  = { "bearer.status.connected",                         "connected",                MMC_S_BEARER_STATUS,              },
     [MMC_F_BEARER_STATUS_CONNECTION_ERROR_NAME]      = { "bearer.status.connection-error.name",             "connection error name",    MMC_S_BEARER_STATUS,              },
     [MMC_F_BEARER_STATUS_CONNECTION_ERROR_MESSAGE]   = { "bearer.status.connection-error.message",          "connection error message", MMC_S_BEARER_STATUS,              },
+    [MMC_F_BEARER_STATUS_DISCONNECT_REQUEST]         = { "bearer.status.disconnect-request",                "disconnect request",       MMC_S_BEARER_STATUS,              },
     [MMC_F_BEARER_STATUS_SUSPENDED]                  = { "bearer.status.suspended",                         "suspended",                MMC_S_BEARER_STATUS,              },
     [MMC_F_BEARER_STATUS_MULTIPLEXED]                = { "bearer.status.multiplexed",                       "multiplexed",              MMC_S_BEARER_STATUS,              },
     [MMC_F_BEARER_STATUS_INTERFACE]                  = { "bearer.status.interface",                         "interface",                MMC_S_BEARER_STATUS,              },
@@ -296,6 +298,7 @@ static FieldInfo field_infos[] = {
     [MMC_F_CBM_PROPERTIES_CHANNEL]                   = { "cbm.properties.channel",                          "channel",                  MMC_S_CBM_PROPERTIES,             },
     [MMC_F_CBM_PROPERTIES_UPDATE]                    = { "cbm.properties.update",                           "update",                   MMC_S_CBM_PROPERTIES,             },
     [MMC_F_CBM_PROPERTIES_MESSAGE_CODE]              = { "cbm.properties.message-code",                     "message code",             MMC_S_CBM_PROPERTIES,             },
+    [MMC_F_CBM_PROPERTIES_LANG        ]              = { "cbm.properties.lang",                             "lang",                     MMC_S_CBM_PROPERTIES,             },
     [MMC_F_SMS_GENERAL_DBUS_PATH]                    = { "sms.dbus-path",                                   "path",                     MMC_S_SMS_GENERAL,                },
     [MMC_F_SMS_CONTENT_NUMBER]                       = { "sms.content.number",                              "number",                   MMC_S_SMS_CONTENT,                },
     [MMC_F_SMS_CONTENT_TEXT]                         = { "sms.content.text",                                "text",                     MMC_S_SMS_CONTENT,                },
