@@ -37,6 +37,7 @@
 #include "mm-modem-helpers.h"
 #include "mm-port-enums-types.h"
 #include "mm-helper-enums-types.h"
+#include "mm-bind.h"
 
 static void async_initable_iface_init (GAsyncInitableIface *iface);
 
@@ -634,7 +635,13 @@ select_profile_3gpp_get_profile_ready (MMIfaceModem3gppProfileManager *modem,
     profile = mm_iface_modem_3gpp_profile_manager_get_profile_finish (modem, res, &error);
     if (!profile)
         g_task_return_error (task, error);
-    else
+    else if (!mm_3gpp_profile_get_enabled (profile)) {
+        g_task_return_new_error (task,
+                                 MM_CORE_ERROR,
+                                 MM_CORE_ERROR_FAILED,
+                                 "Profile '%d' is internally disabled",
+                                 ctx->profile_id);
+    } else
         g_task_return_int (task, ctx->profile_id);
     g_object_unref (task);
 }
@@ -1960,6 +1967,7 @@ mm_broadband_bearer_new (MMBroadbandModem *modem,
         callback,
         user_data,
         MM_BASE_BEARER_MODEM,             modem,
+        MM_BIND_TO,                       G_OBJECT (modem),
         MM_BASE_BEARER_CONFIG,            bearer_properties,
         MM_BROADBAND_BEARER_FLOW_CONTROL, flow_control,
         NULL);
