@@ -27,6 +27,7 @@
 #include "mm-plugin.h"
 #include "mm-log-object.h"
 #include "mm-daemon-enums-types.h"
+#include "mm-bind.h"
 
 static void log_object_iface_init (MMLogObjectInterface *iface);
 
@@ -341,7 +342,7 @@ unexport_modem (MMDevice *self)
     if (path != NULL) {
         g_dbus_object_manager_server_unexport (self->priv->object_manager, path);
         g_object_set (self->priv->modem,
-                      MM_BASE_MODEM_CONNECTION, NULL,
+                      MM_BINDABLE_CONNECTION, NULL,
                       NULL);
         mm_obj_dbg (self, "unexported modem from path '%s'", path);
         g_free (path);
@@ -389,7 +390,7 @@ export_modem (MMDevice *self)
     path = g_strdup_printf (MM_DBUS_MODEM_PREFIX "/%d", mm_base_modem_get_dbus_id (self->priv->modem));
     g_object_set (self->priv->modem,
                   "g-object-path", path,
-                  MM_BASE_MODEM_CONNECTION, connection,
+                  MM_BINDABLE_CONNECTION, connection,
                   NULL);
 
     g_dbus_object_manager_server_export (self->priv->object_manager,
@@ -436,7 +437,7 @@ mm_device_initialize_modem (MMDevice *self)
 
     mm_obj_dbg (self, "modem initializing...");
     mm_base_modem_initialize (modem,
-                              MM_BASE_MODEM_OPERATION_LOCK_REQUIRED,
+                              MM_OPERATION_LOCK_REQUIRED,
                               (GAsyncReadyCallback)initialize_ready,
                               g_object_ref (self));
 }
@@ -459,14 +460,66 @@ clear_modem (MMDevice *self)
     }
 }
 
-void
-mm_device_remove_modem (MMDevice  *self)
+gboolean
+mm_device_remove_modem_finish (MMDevice        *self,
+                               GAsyncResult    *res,
+                               GError         **error)
 {
-    if (!self->priv->modem)
+    return g_task_propagate_boolean (G_TASK (res), error);
+}
+
+static void
+teardown_ports_ready (MMBaseModem  *modem,
+                      GAsyncResult *res,
+                      GTask        *task)
+{
+    MMDevice *self;
+    GError   *error = NULL;
+    gboolean  success;
+
+    self = g_task_get_source_object (task);
+
+    success = mm_base_modem_teardown_ports_finish (modem, res, &error);
+    clear_modem (self);
+
+    if (!success)
+        g_task_return_error (task, error);
+    else
+        g_task_return_boolean (task, TRUE);
+    g_object_unref (task);
+}
+
+void
+mm_device_remove_modem (MMDevice            *self,
+                        GAsyncReadyCallback  callback,
+                        gpointer             user_data)
+{
+    GTask *task;
+
+    task = g_task_new (self, NULL, callback, user_data);
+    if (!self->priv->modem) {
+        g_task_return_boolean (task, TRUE);
+        g_object_unref (task);
         return;
+    }
 
     unexport_modem (self);
-    clear_modem (self);
+    g_cancellable_cancel (mm_base_modem_peek_cancellable (self->priv->modem));
+    mm_base_modem_teardown_ports (self->priv->modem,
+                                  (GAsyncReadyCallback)teardown_ports_ready,
+                                  task);
+}
+
+/* Should only be used from testing code or when the hardware is no longer
+ * present and cannot be gracefully cleaned up.
+ */
+void
+mm_device_remove_modem_quick (MMDevice *self)
+{
+    if (self->priv->modem) {
+        unexport_modem (self);
+        clear_modem (self);
+    }
 }
 
 /*****************************************************************************/
@@ -491,6 +544,25 @@ reprobe (MMDevice *self)
     return G_SOURCE_REMOVE;
 }
 
+static void
+modem_valid_remove_ready (MMDevice     *self,
+                          GAsyncResult *res,
+                          MMBaseModem  *modem)
+{
+    g_autoptr(GError) error = NULL;
+
+    if (!mm_device_remove_modem_finish (self, res, &error))
+        mm_obj_warn (self, "removing modem failed: %s", error->message);
+
+    if (mm_base_modem_get_reprobe (modem)) {
+        if (self->priv->reprobe_id)
+            g_source_remove (self->priv->reprobe_id);
+        self->priv->reprobe_id = g_timeout_add_seconds (REPROBE_SECS, (GSourceFunc)reprobe, self);
+    }
+
+    g_object_unref (modem);
+}
+
 static void
 modem_valid (MMBaseModem *modem,
              GParamSpec  *pspec,
@@ -498,9 +570,9 @@ modem_valid (MMBaseModem *modem,
 {
     if (!mm_base_modem_get_valid (modem)) {
         /* Modem no longer valid */
-        mm_device_remove_modem (self);
-        if (mm_base_modem_get_reprobe (modem))
-            self->priv->reprobe_id = g_timeout_add_seconds (REPROBE_SECS, (GSourceFunc)reprobe, self);
+        mm_device_remove_modem (self,
+                                (GAsyncReadyCallback)modem_valid_remove_ready,
+                                g_object_ref (modem));
     } else {
         /* Modem now valid, export it, but only if we really have it around.
          * It may happen that the initialization sequence fails because the
@@ -732,6 +804,19 @@ mm_device_inhibit_finish (MMDevice      *self,
     return g_task_propagate_boolean (G_TASK (res), error);
 }
 
+static void
+inhibit_disable_modem_remove_ready (MMDevice      *self,
+                                    GAsyncResult  *res,
+                                    GTask         *task)
+{
+    g_autoptr(GError) error = NULL;
+
+    if (!mm_device_remove_modem_finish (self, res, &error))
+        mm_obj_warn (self, "removing modem failed: %s", error->message);
+    g_task_return_boolean (task, TRUE);
+    g_object_unref (task);
+}
+
 static void
 inhibit_disable_ready (MMBaseModem  *modem,
                        GAsyncResult *res,
@@ -742,14 +827,15 @@ inhibit_disable_ready (MMBaseModem  *modem,
 
     self = g_task_get_source_object (task);
 
-    if (!mm_base_modem_disable_finish (modem, res, &error))
+    if (!mm_base_modem_disable_finish (modem, res, &error)) {
         g_task_return_error (task, error);
-    else {
-        g_cancellable_cancel (mm_base_modem_peek_cancellable (modem));
-        mm_device_remove_modem (self);
-        g_task_return_boolean (task, TRUE);
+        g_object_unref (task);
+        return;
     }
-    g_object_unref (task);
+
+    mm_device_remove_modem (self,
+                            (GAsyncReadyCallback)inhibit_disable_modem_remove_ready,
+                            task);
 }
 
 void
@@ -783,8 +869,8 @@ mm_device_inhibit (MMDevice            *self,
      * an exclusive lock marked as override, so the modem object will not
      * allow any additional lock request any more. */
     mm_base_modem_disable (self->priv->modem,
-                           MM_BASE_MODEM_OPERATION_LOCK_REQUIRED,
-                           MM_BASE_MODEM_OPERATION_PRIORITY_OVERRIDE,
+                           MM_OPERATION_LOCK_REQUIRED,
+                           MM_OPERATION_PRIORITY_OVERRIDE,
                            (GAsyncReadyCallback)inhibit_disable_ready,
                            task);
 }
@@ -899,7 +985,7 @@ set_property (GObject *object,
         self->priv->plugin = g_value_dup_object (value);
         break;
     case PROP_MODEM:
-        clear_modem (self);
+        g_assert (self->priv->modem == NULL);
         self->priv->modem = g_value_dup_object (value);
         break;
     case PROP_HOTPLUGGED:
